@@ -63,7 +63,7 @@ class LearningMachine(object):
                step=20000,
                md_step=20,
                MaxMDstep=500,
-               mpopt=3,
+               mpopt=1,
                messages=1,
                T=300,
                Tmax=1000,
@@ -84,6 +84,7 @@ class LearningMachine(object):
                rodic=None,
                rtole=0.55,
                bondTole=1.3,
+               CheckBond=True,
                EngTole=0.05,
                dEtole=0.2,
                d2Etole=0.05,
@@ -119,7 +120,8 @@ class LearningMachine(object):
       self.resetAcc     = resetAcc    # reset accuracy criteria after this train cycle
       self.rtole        = rtole       # minimum bond length used to supervise ML-MD simulation
       self.bondTole     = bondTole
-      self.convergence   = convergence
+      self.CheckBond    = CheckBond
+      self.convergence  = convergence
       self.nconvergence = nconvergence
       self.learnWay     = learnWay    # the way of learing
       self.ncpu         = ncpu
@@ -184,7 +186,8 @@ class LearningMachine(object):
       else:
          self.label     = label
 
-      with open('learning.log','w') as l:
+      if not isfile('learning.log'):
+         with open('learning.log','w') as l:
            print('------------------------------------------------------------------------',file=l)
            print('-                                                                      -',file=l)
            print('-            On-the-Fly Learning-Machine by SIESTA and IRFF            -',file=l)
@@ -241,16 +244,16 @@ class LearningMachine(object):
           if learnWay==4 and lw4:
              atoms,lw4 = self.c.bond_momenta(atoms)
           else:
-             bondBroken = self.c.check_bond(atoms=atoms,bondTole=self.bondTole)
-          if not lw4: learnWay = 3
-          
-          if bondBroken>=3:
-             atoms = read(self.initConfig)
-             atoms = self.c.bond_momenta_bigest(atoms)
-             e_gmd,mdsteps = self.mlmd(cwd,run_dir,atoms,100000,i,learnWay) 
-
-          atoms.write('poscar.gen')                                   # for aimd
-
+             bondBroken,bkbd = self.c.check_bond(atoms=atoms,bondTole=self.bondTole)
+          if not lw4: learnWay = 3                                     
+          if bondBroken>=1 and self.CheckBond and (not bkbd is None):  # if bonds have broken
+             mdsteps = 10
+             images = self.c.stretch(bkbd,atoms=atoms,nbin=mdsteps,st=self.bondTole-0.015,ed=1.0,scale=1.2,traj='md.traj')
+             if images is None:
+                atoms = self.c.bond_momenta_bigest(atoms)
+                e_gmd,mdsteps = self.mlmd(cwd,run_dir,atoms,100000,i,learnWay) 
+     
+          atoms.write('poscar.gen')                                    # for aimd
           if learnWay>=3: 
              dft_step = int(mdsteps/self.colFrame)+1
           else:
@@ -261,7 +264,7 @@ class LearningMachine(object):
                                                                        # start training  
           trajs_ = prep_data(label=self.label,direcs=data_dir,
                              split_batch=self.batch,max_batch=self.max_batch,
-                             frame=1000,dft='siesta')              # get trajs for training
+                             frame=1000,dft='siesta')                  # get trajs for training
           with open('training.log','w') as fe:                         # 
                fe.write('## training loss and accuries\n')             #
           trajs_.update(self.direcs)                                   #
@@ -300,8 +303,9 @@ class LearningMachine(object):
                 tIter += 1
 
           self.lossCriteria = float(loss)
+
           e_gmd,mdsteps = self.mlmd(cwd,run_dir,atoms,100000,i,learnWay) 
-          step += mdsteps                                     # run ML-MD test training results     
+          step += mdsteps                                          # run ML-MD test training results     
 
           if accu >= self.accCriteria and tstep<self.step and tIter<=2: # get md steps
              if self.md_step<self.MaxMDstep and mdsteps>=self.md_step:
@@ -323,19 +327,18 @@ class LearningMachine(object):
           diff  = abs(e_gmd[0]-e_aimd[0])
           it.append(i)
 
-          plot_energies(it,e_siesta,e_gulp)                           # plot learning status 
-                                                                      #
-          with open('energies.log','a') as fe:                        # write learning status 
-               for i_,e_ in enumerate(e_gmd):                         # to file
-                   if i_==0:                                          #
-                      fe.write(' %d %f %f diff: %f \n' %(step+i_,e_gmd[i_],e_aimd[0],diff))
-                   else:                                              #
-                      fe.write(' %d %f \n' %(step+i_,e_gmd[i_]))      #
-          
-          with open('learning.log','a') as l:
-               l.write('Iter: %d loss: %f acc: %f mds: %d Eirff: %f Esiesta: %f dEmax: %f d2Emax: %f\n' %(i,
-                        loss,accu,mdsteps,e_gmd[i_],e_aimd[0],dEmax_,d2Emax_))
+          plot_energies(it,e_siesta,e_gulp)                             # plot learning status 
+                                                                        #
+         #  with open('energies.log','a') as fe:                        # write learning status 
+         #       for i_,e_ in enumerate(e_gmd):                         # to file
+         #           if i_==0:                                          #
+         #              fe.write(' %d %f %f diff: %f \n' %(step+i_,e_gmd[i_],e_aimd[0],diff))
+         #           else:                                              #
+         #              fe.write(' %d %f \n' %(step+i_,e_gmd[i_]))      #
 
+          self.learninglog(i,loss,accu,mdsteps,e_gulp[-1],e_siesta[-1],dEmax_,d2Emax_,learnWay,
+                           bondBroken,bkbd)
+          
           converg_ = converg
           if diff<=self.convergence: 
              converg = True
@@ -358,6 +361,23 @@ class LearningMachine(object):
           i += 1
 
 
+  def learninglog(self,i,loss,accu,mdsteps,eirff,edft,dEmax,d2Emax,learnWay,bondBroken,bkbd):
+      with open('learning.log','a') as l:
+         l.write('                  ====================================                  \n')
+         l.write('                      Learning iteration:  %4d                         \n' %i)
+         l.write('                  ====================================                  \n')
+         l.write(' \n')
+         l.write('Loss of the model:  %f  \n' %loss)
+         l.write('Accuracy of the ML model:  %f  \n' %accu)
+         l.write('Steps of the ML MD:  %d  \n' %mdsteps)
+         l.write('Energy from ML and DFT:  %f  .vs.  %f \n' %(eirff,edft))
+         l.write('The max first derivative and second derivative:  %f,  %f \n' %(dEmax,d2Emax))
+         l.write('The learning method of this iter:  %d \n' %learnWay)
+         # l.write('Bond Broken :  %d \n' %bondBroken)
+         if bondBroken>=1 and (not bkbd is None):
+            l.write('Bond between atoms %d and %d was broken during MLMD.\n' %(bkbd[0],bkbd[1]))
+         l.write(' \n')
+
   def aimd(self,cwd,run_dir,tstep,gen,learnWay):
       mkdir(run_dir)
       chdir(cwd+'/'+run_dir)
@@ -432,6 +452,7 @@ class LearningMachine(object):
            InPut = {'accCriteria':self.accCriteria,
                     'lossCriteria':self.lossCriteria,
                     'lossTole':self.lossTole,
+                    'bondTole':self.bondTole,
                     'accTole':self.accTole,
                     'accMax':self.accMax,
                     'accInc':self.accInc,
@@ -465,6 +486,7 @@ class LearningMachine(object):
            self.accCriteria  = InPut['accCriteria']
            self.lossCriteria = InPut['lossCriteria']
            self.lossTole     = InPut['lossTole']
+           self.bondTole     = InPut['bondTole']
            self.accTole      = InPut['accTole']
            self.accMax       = InPut['accMax']
            self.accInc       = InPut['accInc']
