@@ -54,7 +54,7 @@ class MPNN(ReaxFF):
                MessageFunction=1,
                spec=[],
                sort=False,
-               pkl=True,
+               pkl=False,
                bo_penalty=100000.0,
                optMethod='ADAM',
                maxstep=60000,
