@@ -134,7 +134,7 @@ class ReaxFF(object):
                bo_layer=[8,4],
                spec=[],
                sort=False,
-               pkl=True,
+               pkl=False,
                popSize=500,
                fromPop=False,
                board=False,
@@ -2070,4 +2070,5 @@ def test_reax(direcs=None,batch_size=200,dft='siesta'):
     rn.sess.close()
 
 
-
+if __name__ == '__main__':
+   main()
